miml.data package
=================

Submodules
----------

miml.data.bag module
--------------------

.. automodule:: miml.data.bag
   :members:
   :undoc-members:
   :show-inheritance:

miml.data.instance module
-------------------------

.. automodule:: miml.data.instance
   :members:
   :undoc-members:
   :show-inheritance:

miml.data.miml\_dataset module
------------------------------

.. automodule:: miml.data.miml_dataset
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: miml.data
   :members:
   :undoc-members:
   :show-inheritance:
